@@ -288,7 +288,7 @@ class YAMLConfig(ABC):
                 value = params.typecast(value)
             schema_extra['properties'][name] = {
                 'title': params.kwarg_alias or name,
-                'description': params.docstring + f" (default: {value})",
+                'description': (cls._get_cls_prop_doc(name) or params.docstring or '') + f" (default: {value})",
             }
         # create the model
         out = create_model(
